@@ -38,11 +38,11 @@ def rand_string(length):
 
 def receive_management(zmq_config, subscribe_callback, unsubscribe_callback):
     """
-        Management endpoint to handle (un)subscriptions of VAST-bridge
-        instances.
-        @param zmq_config Config object for the ZeroMQ endpoints
-        @param subscribe_callback Callback from Threat Bus to unsubscribe new apps
-        @param unsubscribe_callback Callback from Threat Bus to unsubscribe apps
+    Management endpoint to handle (un)subscriptions of VAST-bridge
+    instances.
+    @param zmq_config Config object for the ZeroMQ endpoints
+    @param subscribe_callback Callback from Threat Bus to unsubscribe new apps
+    @param unsubscribe_callback Callback from Threat Bus to unsubscribe apps
     """
     global logger, lock, subscriptions
 
@@ -103,15 +103,19 @@ def pub_zmq(zmq_config):
 
     while True:
         lock.acquire()
-        for topic, q in subscriptions.items():
+        subs_copy = subscriptions.copy()
+        lock.release()
+        for topic, q in subs_copy.items():
             if q.empty():
                 continue
             msg = q.get()
             if not msg:
                 continue
             intel = map_intel_to_vast(msg)
-            socket.send((f"{topic} {intel}").encode())
-        lock.release()
+            if intel:
+                socket.send((f"{topic} {intel}").encode())
+                logger.debug(f"Published {intel} on topic {topic}")
+            q.task_done()
         time.sleep(0.05)
 
 
@@ -156,4 +160,4 @@ def run(config, logging, inq, subscribe_callback, unsubscribe_callback):
         args=(config["zmq"], subscribe_callback, unsubscribe_callback),
         daemon=True,
     ).start()
-    logger.info(f"VAST plugin started")
+    logger.info("VAST plugin started")
