@@ -25,8 +25,17 @@ setup(
     ],
     description="A plugin to enable threatbus communication with VAST.",
     entry_points={"threatbus.app": ["vast = threatbus_vast.plugin"]},
-    install_requires=["threatbus>=2020.04.29", "pyzmq>=19", "pyvast>=2020.03.26",],
-    keywords=["threatbus", "vast", "threat intelligence", "zeromq",],
+    install_requires=[
+        "threatbus>=2020.09.30",
+        "pyzmq>=19",
+        "python-dateutil>=2.8.1",
+    ],
+    keywords=[
+        "threatbus",
+        "vast",
+        "threat intelligence",
+        "zeromq",
+    ],
     license="BSD 3-clause",
     long_description=long_description,
     long_description_content_type="text/markdown",
@@ -35,5 +44,5 @@ setup(
     packages=["threatbus_vast"],
     python_requires=">=3.7",
     url="https://github.com/tenzir/threatbus",
-    version="2020.07.28",
+    version="2020.09.30",
 )
